@@ -28,18 +28,6 @@ class RedisClient(ClientModel):
     def hgetall(self, array_name:str) -> list:
         return self.redis.hgetall(array_name)
 
-    def get_redis(self) -> redis.Redis:
-        return self.redis
-
-    def get_host(self) -> str:
-        return self.host
-
-    def get_port(self) -> str:
-        return self.port
-
-    def get_db(self) -> str:
-        return self.db
-
     def set_dict_using_global_selector(self, global_selector:str, array_name:str, set_item_key:str):
         array = self.hgetall(array_name)
         for key in array:
